function [x,t] = EulerCoupled(MyFunc,InitialValues,Start,Finish,Nsteps)
% solves the initial value problem dx/dt = f(x)
% Uses the Euler method
% Myfunc = Handle to the function which calculates F(x)
% InitialValues = starting values (a column vector)
% Start = start time
% finish = end time
% Nsteps = number of steps to march forward
x(:,1) = InitialValues;
t(1) = Start;
%calculate the time ste
dt = (Finish-Start)/Nsteps;
for i = 1:Nsteps
    %calculate the gradient using the current solution (time = t)
    %the function should now return a vector of gradients
    F = feval(MyFunc, x(:,i),t(i));
   %calculate the new value of x and t
    t(i+1) = dt + t(i);
   x(:,i+1) = F*dt + x(:,i);
end
t = t';
x = x';
return